.. -- Software -----------------------

.. |cWB| replace:: cWB
.. _cWB: https://gwburst.gitlab.io/documentation/latest/html/

.. |cWBl| replace:: coherent WaveBurst (cWB)
.. _cWBl: https://gwburst.gitlab.io/documentation/latest/html/

.. |framel| replace:: `framel`
.. _framel: http://lappweb.in2p3.fr/virgo/FrameL/

.. |GstLAL| replace:: GstLAL
.. _GstLAL: https://lscsoft.docs.ligo.org/gstlal/

.. |htgettoken| replace:: `htgettoken`
.. _htgettoken: https://github.com/fermitools/htgettoken

.. |LDAStools.frameCPP| replace:: `LDAStools.frameCPP`
.. _LDAStools.frameCPP: https://computing.docs.ligo.org/ldastools/LDAS_Tools/ldas-tools-framecpp/

.. |lal| replace:: `lal`
.. _lal: https://lscsoft.docs.ligo.org/lalsuite/lal/

.. |lal.FrDetector| replace:: `lal.FrDetector`
.. _lal.FrDetector: https://lscsoft.docs.ligo.org/lalsuite/lal/struct_l_a_l_fr_detector.html

.. |lal.LIGOTimeGPS| replace:: `lal.LIGOTimeGPS`
.. _lal.LIGOTimeGPS: https://lscsoft.docs.ligo.org/lalsuite/lal/struct_l_i_g_o_time_g_p_s.html

.. |lal.REAL8TimeSeries| replace:: `lal.REAL8TimeSeries`
.. _lal.REAL8TimeSeries: https://lscsoft.docs.ligo.org/lalsuite/lal/struct_r_e_a_l8_time_series.html

.. |lal.Unit| replace:: `lal.Unit`
.. _lal.Unit: https://lscsoft.docs.ligo.org/lalsuite/lal/struct_l_a_l_unit.html

.. |lalframe| replace:: `lalframe`
.. _lalframe: https://lscsoft.docs.ligo.org/lalsuite/lalframe/

.. |lalframe.FrStream| replace:: `lalframe.FrStream`
.. _lalframe.FrStream: https://lscsoft.docs.ligo.org/lalsuite/lalframe/struct_l_a_l_fr_stream.html

.. |MySQLdb| replace:: `MySQLdb`
.. _MySQLdb: http://mysql-python.sourceforge.net/

.. |nds2| replace:: ``NDS2``
.. _nds2: https://wiki.ligo.org/Computing/NDSClient

.. |nds2l| replace:: Network Data Server (NDS2)
.. _nds2l: https://wiki.ligo.org/Computing/NDSClient

.. -- Other references ---------------

.. |GravitySpy| replace:: Gravity Spy
.. _GravitySpy: https://gravityspy.org

.. |GWOSCl| replace:: The Gravitational-Wave Open Science Centre (GWOSC)
.. _GWOSCl: https://gwosc.org/

.. |GWOSC| replace:: GWOSC
.. _GWOSC: https://gwosc.org/

.. |OSDF| replace:: OSDF
.. _OSDF: https://osg-htc.org/services/osdf.html

.. |OSDFl| replace:: the Open Science Data Federation (OSDF)
.. _OSDFl: https://osg-htc.org/services/osdf.html

.. |Pelican| replace:: Pelican
.. _Pelican: https://pelicanplatform.org/

.. -- Data releases ------------------

.. |GWOSC_AUX_GW170817| replace:: Auxiliary Channel Three Hour Release
.. _GWOSC_AUX_GW170817: https://gwosc.org/auxiliary/GW170814/

.. |GWOSC_O3_AUX_RELEASE| replace:: O3 Auxiliary Channel Data Release
.. _GWOSC_O3_AUX_RELEASE: https://gwosc.org/O3/auxiliary/

.. |GWOSC_O3_AUX_TREND_RELEASE| replace:: O3 Second-trend Data Release
.. _GWOSC_O3_AUX_TREND_RELEASE: https://gwosc.org/O3/trend/

.. |GWOSC_O4_AUX_RELEASE| replace:: O4 Auxiliary Channel Data Release
.. _GWOSC_O4_AUX_RELEASE: https://gwosc.org/O4/auxiliary/

.. -- Event science summaries --------

.. catalogues

.. |GWTCl| replace:: Gravitational-Wave Transient Catalogue (GWTC)
.. _GWTCl: https://gwosc.org/eventapi/html/GWTC/

.. |GWTC| replace:: GWTC
.. _GWTC: https://gwosc.org/eventapi/html/GWTC/

.. |GWTC-1l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 1
.. _GWTC-1l: https://gwosc.org/GWTC-1/

.. |GWTC-1| replace:: GWTC-1
.. _GWTC-1: https://gwosc.org/GWTC-1/

.. |GWTC-2l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 2
.. _GWTC-2l: https://gwosc.org/GWTC-2/

.. |GWTC-2| replace:: GWTC-2
.. _GWTC-2: https://gwosc.org/GWTC-2/

.. |GWTC-2.1l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 2.1
.. _GWTC-2.1l: https://gwosc.org/GWTC-2.1/

.. |GWTC-2.1| replace:: GWTC-2.1
.. _GWTC-2.1: https://gwosc.org/GWTC-2.1/

.. |GWTC-3l| replace:: Gravitational-Wave Transient Catalogue (GWTC) 3
.. _GWTC-3l: https://gwosc.org/GWTC-3/

.. |GWTC-3| replace:: GWTC-3
.. _GWTC-3: https://gwosc.org/GWTC-3/

.. events

.. |GW150914| replace:: GW150914
.. _GW150914: https://ligo.org/detections/gw150914/

.. |GW170814| replace:: GW170814
.. _GW170814: https://ligo.org/detections/gw170814/

.. |GW170817| replace:: GW170817
.. _GW170817: https://ligo.org/detections/gw170817/

.. |GW200105| replace:: GW200105
.. _GW200105: https://ligo.org/gw200105-gw200115/

.. |GW200115| replace:: GW200115
.. _GW200115: https://ligo.org/gw200105-gw200115/

.. |GW200129| replace:: GW200129
.. _GW200129: https://gwosc.org/eventapi/html/GWTC-3-confident/GW200129_065458/

.. |GW230529| replace:: GW230529
.. _GW230529: https://ligo.org/detections/gw230529/
